Package: nascaR.data
Title: NASCAR Race Data
Version: 3.1.0
Authors@R: 
    c(
        person(
            given = "Kyle",
            family = "Grealis",
            email = "kyle@kylegrealis.com",
            role = c("aut", "cre"),
            comment = c(ORCID = "0000-0002-9223-8854")
        ),
        person(
            given = "Nick",
            family = "Triplett",
            role = "ctb",
            email = "nicholas.triplett@siu.edu"
        ),
        person(
            given = "Gabriel",
            family = "Odom",
            role = "ctb",
            email = "gabriel.odom@fiu.edu",
            comment = c(ORCID = "0000-0003-1341-4555")
        )
    )
Description: A collection of NASCAR race, driver, owner and manufacturer
    data across the three major NASCAR divisions: NASCAR Cup Series, NXS,
    and NASCAR Craftsman Truck Series. The curated
    data begins with the 1949 season and is updated weekly during the
    racing season. Explore race, season, or career performance for drivers,
    teams, and manufacturers throughout NASCAR's history. Data was sourced
    with permission from DriverAverages.com.
License: GPL (>= 3)
Depends: R (>= 4.1.0)
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: arrow, dplyr, glue, rlang, stringdist, stringr
Suggests: conflicted, curl, ggtext, httr2, jsonlite, knitr,
        paws.storage, purrr, rmarkdown, roxygen2, rvest, scales,
        testthat (>= 3.0.0), tidyverse
Config/testthat/edition: 3
VignetteBuilder: knitr
URL: https://www.kylegrealis.com/nascaR.data/
BugReports: https://github.com/kyleGrealis/nascaR.data/issues
NeedsCompilation: no
Packaged: 2026-06-11 00:50:33 UTC; kyle
Author: Kyle Grealis [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-9223-8854>),
  Nick Triplett [ctb],
  Gabriel Odom [ctb] (ORCID: <https://orcid.org/0000-0003-1341-4555>)
Maintainer: Kyle Grealis <kyle@kylegrealis.com>
Repository: CRAN
Date/Publication: 2026-06-11 07:00:02 UTC
Built: R 4.6.0; ; 2026-06-11 10:00:11 UTC; unix
