# Generated by roxygen2: do not edit by hand

export(clear_cache)
export(export_series)
export(get_driver_info)
export(get_manufacturer_info)
export(get_team_info)
export(load_series)
importFrom(dplyr,bind_rows)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,n_distinct)
importFrom(dplyr,summarize)
importFrom(glue,glue)
importFrom(rlang,abort)
importFrom(stringdist,stringdist)
importFrom(stringr,fixed)
importFrom(stringr,str_detect)
importFrom(stringr,str_split)
importFrom(stringr,str_starts)
importFrom(stringr,str_to_lower)
importFrom(stringr,str_trim)
importFrom(utils,head)
